pub struct WasiCliNamed<T>(/* private fields */);Expand description
A helper struct which implements HasData for the wasi:cli APIs when
used in combination with named imports.
This structure is similar in purpose to WasiCli and is used
when using the named_imports module for wasi:cli. This structure
serves as the D type parameter for add_to_linker functions.
Meaning of the T parameter
Here the T must be something that implements WasiCliNamedView. The
corresponding Data for this type is WasiCtxNamedView which internally
will contain &mut T.
Effectively you’re going to implement WasiCliNamedView for something in
your embedding, and that’s the T you’ll fill in here.
Examples
use wasmtime::component::{Linker, Component, ResourceTable};
use wasmtime::{Engine, Result};
use wasmtime_wasi::{NamedId, WasiCtxNamedView};
use wasmtime_wasi::cli::*;
use wasmtime_wasi::p2::bindings::named_imports;
use std::collections::HashMap;
struct MyStoreState {
table: ResourceTable,
states: HashMap<NamedId, WasiCliCtx>,
}
fn main() -> Result<()> {
let engine = Engine::default();
let mut linker = Linker::new(&engine);
let component = Component::new(&engine, "(component)")?;
let mut name_map = HashMap::new();
named_imports::wasi::cli::environment::add_to_linker::<MyStoreState, WasiCliNamed<MyStoreState>>(
&mut linker,
&component,
|name| {
let len = name_map.len();
Ok(NamedId(*name_map.entry(name.to_string()).or_insert(len)))
},
|state| WasiCtxNamedView(state),
)?;
Ok(())
}
impl WasiCliNamedView for MyStoreState {
fn cli(&mut self, id: NamedId) -> WasiCliCtxView<'_> {
let ctx = self.states.get_mut(&id).expect("state for id");
WasiCliCtxView {
table: &mut self.table,
ctx,
}
}
}Trait Implementations
Sourceimpl<T> HasData for WasiCliNamed<T>where
T: WasiCliNamedView,
impl<T> HasData for WasiCliNamed<T>where
T: WasiCliNamedView,
Sourcetype Data<'a> = WasiCtxNamedView<'a, T>
type Data<'a> = WasiCtxNamedView<'a, T>
The data associated with this trait implementation, chiefly used as a
generic associated type to allow plumbing the
'a lifetime into the
definition here. Read moreSourceimpl<T, U> HostWithStore<U> for WasiCliNamed<T>where
T: WasiCliNamedView,
Available on crate feature p3 only.
impl<T, U> HostWithStore<U> for WasiCliNamed<T>where
T: WasiCliNamedView,
Available on crate feature
p3 only.Sourcefn read_via_stream(
store: Access<'_, U, Self>,
id: NamedId,
) -> Result<(StreamReader<u8>, FutureReader<Result<(), ErrorCode>>)>
fn read_via_stream( store: Access<'_, U, Self>, id: NamedId, ) -> Result<(StreamReader<u8>, FutureReader<Result<(), ErrorCode>>)>
Return a stream for reading from stdin. Read more
Sourceimpl<T, U> HostWithStore<U> for WasiCliNamed<T>where
T: WasiCliNamedView,
Available on crate feature p3 only.
impl<T, U> HostWithStore<U> for WasiCliNamed<T>where
T: WasiCliNamedView,
Available on crate feature
p3 only.Sourcefn write_via_stream(
store: Access<'_, U, Self>,
id: NamedId,
data: StreamReader<u8>,
) -> Result<FutureReader<Result<(), ErrorCode>>>
fn write_via_stream( store: Access<'_, U, Self>, id: NamedId, data: StreamReader<u8>, ) -> Result<FutureReader<Result<(), ErrorCode>>>
Write the given stream to stdout. Read more
Sourceimpl<T, U> HostWithStore<U> for WasiCliNamed<T>where
T: WasiCliNamedView,
Available on crate feature p3 only.
impl<T, U> HostWithStore<U> for WasiCliNamed<T>where
T: WasiCliNamedView,
Available on crate feature
p3 only.Sourcefn write_via_stream(
store: Access<'_, U, Self>,
id: NamedId,
data: StreamReader<u8>,
) -> Result<FutureReader<Result<(), ErrorCode>>>
fn write_via_stream( store: Access<'_, U, Self>, id: NamedId, data: StreamReader<u8>, ) -> Result<FutureReader<Result<(), ErrorCode>>>
Write the given stream to stderr. Read more