WasiClocksNamed

Struct WasiClocksNamed 

pub struct WasiClocksNamed<T>(/* private fields */);
A helper struct which implements HasData for the wasi:clocks APIs when used in combination with named imports.

This structure is similar in purpose to WasiClocks and is used when using the named_imports module for wasi:clocks. This structure serves as the D type parameter for add_to_linker functions.

Meaning of the T parameter

Here the T must be something that implements WasiClocksNamedView. The corresponding Data for this type is WasiCtxNamedView which internally will contain &mut T.

Effectively you’re going to implement WasiClocksNamedView for something in your embedding, and that’s the T you’ll fill in here.

Examples

use wasmtime::component::{Linker, Component, ResourceTable};
use wasmtime::{Engine, Result};
use wasmtime_wasi::{NamedId, WasiCtxNamedView};
use wasmtime_wasi::clocks::*;
use wasmtime_wasi::p2::bindings::named_imports;
use std::collections::HashMap;

struct MyStoreState {
    table: ResourceTable,
    states: HashMap<NamedId, WasiClocksCtx>,
}

fn main() -> Result<()> {
    let engine = Engine::default();
    let mut linker = Linker::new(&engine);
    let component = Component::new(&engine, "(component)")?;
    let mut name_map = HashMap::new();

    named_imports::wasi::clocks::wall_clock::add_to_linker::<MyStoreState, WasiClocksNamed<MyStoreState>>(
        &mut linker,
        &component,
        |name| {
            let len = name_map.len();
            Ok(NamedId(*name_map.entry(name.to_string()).or_insert(len)))
        },
        |state| WasiCtxNamedView(state),
    )?;
    Ok(())
}

impl WasiClocksNamedView for MyStoreState {
    fn clocks(&mut self, id: NamedId) -> WasiClocksCtxView<'_> {
        let ctx = self.states.get_mut(&id).expect("state for id");
        WasiClocksCtxView {
            table: &mut self.table,
            ctx,
        }
    }
}