pub trait Host {
// Required method
fn get_terminal_stdin(&mut self) -> Result<Option<Resource<TerminalInput>>>;
}Required Methods
Sourcefn get_terminal_stdin(&mut self) -> Result<Option<Resource<TerminalInput>>>
fn get_terminal_stdin(&mut self) -> Result<Option<Resource<TerminalInput>>>
If stdin is connected to a terminal, return a terminal-input handle
allowing further interaction with it.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementations on Foreign Types
Sourceimpl<_T: Host + ?Sized> Host for &mut _T
impl<_T: Host + ?Sized> Host for &mut _T
Sourcefn get_terminal_stdin(&mut self) -> Result<Option<Resource<TerminalInput>>>
fn get_terminal_stdin(&mut self) -> Result<Option<Resource<TerminalInput>>>
If stdin is connected to a terminal, return a terminal-input handle
allowing further interaction with it.