Host

Trait Host 

pub trait Host {
    // Required method
    fn get_directories(&mut self) -> Result<Vec<(Resource<Descriptor>, String)>>;
}

Required Methods

fn get_directories(&mut self) -> Result<Vec<(Resource<Descriptor>, String)>>

Return the set of preopened directories, and their paths.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<_T: Host + ?Sized> Host for &mut _T

Source

fn get_directories(&mut self) -> Result<Vec<(Resource<Descriptor>, String)>>

Return the set of preopened directories, and their paths.

Implementors