Advice

Enum Advice 

#[repr(u8)]
pub enum Advice { Normal = 0, Sequential = 1, Random = 2, WillNeed = 3, DontNeed = 4, NoReuse = 5, }
File or memory access pattern advisory information.

Variants



Normal = 0

The application has no advice to give on its behavior with respect to the specified data.



Sequential = 1

The application expects to access the specified data sequentially from lower offsets to higher offsets.



Random = 2

The application expects to access the specified data in a random order.



WillNeed = 3

The application expects to access the specified data in the near future.



DontNeed = 4

The application expects that it will not access the specified data in the near future.



NoReuse = 5

The application expects to access the specified data once and then not reuse it thereafter.