Host

Trait Host 

pub trait Host {
    // Required method
    fn get_terminal_stderr(
        &mut self,
    ) -> Result<Option<Resource<TerminalOutput>>>;
}

Required Methods

fn get_terminal_stderr(&mut self) -> Result<Option<Resource<TerminalOutput>>>

If stderr is connected to a terminal, return a terminal-output handle allowing further interaction with it.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<_T: Host + ?Sized> Host for &mut _T

Source

fn get_terminal_stderr(&mut self) -> Result<Option<Resource<TerminalOutput>>>

If stderr is connected to a terminal, return a terminal-output handle allowing further interaction with it.

Implementors