Trait HostError
pub trait HostError {
// Required methods
fn to_debug_string(
&mut self,
self_: Resource<Error>,
) -> Result<String, Error>;
fn drop(&mut self, rep: Resource<Error>) -> Result<(), Error>;
}Required Methods
fn to_debug_string(&mut self, self_: Resource<Error>) -> Result<String, Error>
fn to_debug_string(&mut self, self_: Resource<Error>) -> Result<String, Error>
Returns a string that is suitable to assist humans in debugging this error.
WARNING: The returned string should not be consumed mechanically! It may change across platforms, hosts, or other implementation details. Parsing this string is a major platform-compatibility hazard.
fn drop(&mut self, rep: Resource<Error>) -> Result<(), Error>
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementations on Foreign Types
impl HostError for ResourceTable
impl HostError for ResourceTable
impl<_T> HostError for &mut _T
impl<_T> HostError for &mut _T
fn to_debug_string(&mut self, self_: Resource<Error>) -> Result<String, Error>
fn to_debug_string(&mut self, self_: Resource<Error>) -> Result<String, Error>
Returns a string that is suitable to assist humans in debugging this error.
WARNING: The returned string should not be consumed mechanically! It may change across platforms, hosts, or other implementation details. Parsing this string is a major platform-compatibility hazard.