pub trait HostPollable {
// Required methods
fn ready(&mut self, self_: Resource<Pollable>) -> Result<bool>;
fn block(&mut self, self_: Resource<Pollable>) -> Result<()>;
fn drop(&mut self, rep: Resource<Pollable>) -> Result<()>;
}Required Methods
Sourcefn ready(&mut self, self_: Resource<Pollable>) -> Result<bool>
fn ready(&mut self, self_: Resource<Pollable>) -> Result<bool>
Return the readiness of a pollable. This function never blocks.
Returns true when the pollable is ready, and false otherwise.
Sourcefn block(&mut self, self_: Resource<Pollable>) -> Result<()>
fn block(&mut self, self_: Resource<Pollable>) -> Result<()>
block returns immediately if the pollable is ready, and otherwise
blocks until ready.
This function is equivalent to calling poll.poll on a list
containing only this pollable.
fn drop(&mut self, rep: Resource<Pollable>) -> Result<()>
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementations on Foreign Types
Sourceimpl HostPollable for ResourceTable
impl HostPollable for ResourceTable
Sourceimpl<_T: HostPollable + ?Sized> HostPollable for &mut _T
impl<_T: HostPollable + ?Sized> HostPollable for &mut _T
Sourcefn ready(&mut self, self_: Resource<Pollable>) -> Result<bool>
fn ready(&mut self, self_: Resource<Pollable>) -> Result<bool>
Return the readiness of a pollable. This function never blocks.
Returns true when the pollable is ready, and false otherwise.
Sourcefn block(&mut self, self_: Resource<Pollable>) -> Result<()>
fn block(&mut self, self_: Resource<Pollable>) -> Result<()>
block returns immediately if the pollable is ready, and otherwise
blocks until ready.
This function is equivalent to calling poll.poll on a list
containing only this pollable.