pub struct Network { /* private fields */ }Expand description
A network resource representing the capability to use the networking APIs in WASI 0.2. The concept of network handles has been removed in WASI 0.3.
Note that in Wasmtime all permissions are checked through the WasiCtx and
not through the Network resource itself. The Network resource is just a
placeholder capability handle.