pub trait Host {
// Required method
fn get_terminal_stderr(
&mut self,
) -> Result<Option<Resource<TerminalOutput>>>;
}Available on crate feature
p3 only.Required Methods
Sourcefn get_terminal_stderr(&mut self) -> Result<Option<Resource<TerminalOutput>>>
fn get_terminal_stderr(&mut self) -> Result<Option<Resource<TerminalOutput>>>
If stderr is connected to a terminal, return a terminal-output handle
allowing further interaction with it.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementations on Foreign Types
Sourceimpl<_T: Host + ?Sized> Host for &mut _T
impl<_T: Host + ?Sized> Host for &mut _T
Sourcefn get_terminal_stderr(&mut self) -> Result<Option<Resource<TerminalOutput>>>
fn get_terminal_stderr(&mut self) -> Result<Option<Resource<TerminalOutput>>>
If stderr is connected to a terminal, return a terminal-output handle
allowing further interaction with it.