Host

Trait Host 

pub trait Host {
    // Required method
    fn get_terminal_stdout(
        &mut self,
    ) -> Result<Option<Resource<TerminalOutput>>>;
}
Available on crate feature p3 only.

Required Methods

fn get_terminal_stdout(&mut self) -> Result<Option<Resource<TerminalOutput>>>

If stdout is connected to a terminal, return a terminal-output handle allowing further interaction with it.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<_T: Host + ?Sized> Host for &mut _T

Source

fn get_terminal_stdout(&mut self) -> Result<Option<Resource<TerminalOutput>>>

If stdout is connected to a terminal, return a terminal-output handle allowing further interaction with it.

Implementors