pub struct TcpSocket { /* private fields */ }p3 only.Expand description
A TCP socket resource.
The socket can be in one of the following states:
unboundbound(See note below)listeningconnectingconnectedclosedSee https://github.com/WebAssembly/WASI/blob/main/proposals/sockets/TcpSocketOperationalSemantics-0.3.0-draft.md for more information.
Note: Except where explicitly mentioned, whenever this documentation uses
the term “bound” without backticks it actually means: in the bound state or higher.
(i.e. bound, listening, connecting or connected)
WASI uses shared ownership semantics: the tcp-socket handle and all
derived stream and future values reference a single underlying OS
socket:
- Send/receive streams remain functional after the original
tcp-sockethandle is dropped. - The stream returned by
listenbehaves similarly. - Client sockets returned by
tcp-socket::listenare independent and do not keep the listening socket alive.
The OS socket is closed only after the last handle is dropped. This model has observable effects; for example, it affects when the local port binding is released.
In addition to the general error codes documented on the
types::error-code type, TCP socket methods may always return
error(invalid-state) when in the closed state.
A host TCP socket, plus associated bookkeeping.