pub struct WasiRandomNamed<T>(/* private fields */);Expand description
A helper struct which implements HasData for the wasi:random APIs
when used in combination with named imports.
This structure is similar in purpose to WasiRandom and is used
when using the named_imports module for wasi:random. This structure
serves as the D type parameter for add_to_linker functions.
Meaning of the T parameter
Here the T must be something that implements WasiRandomNamedView. The
corresponding Data for this type is WasiCtxNamedView which internally
will contain &mut T.
Effectively you’re going to implement WasiRandomNamedView for something in
your embedding, and that’s the T you’ll fill in here.
Examples
use wasmtime::component::{Linker, Component};
use wasmtime::{Engine, Result};
use wasmtime_wasi::{NamedId, WasiCtxNamedView};
use wasmtime_wasi::random::*;
use wasmtime_wasi::p2::bindings::named_imports;
use std::collections::HashMap;
struct MyStoreState {
states: HashMap<NamedId, WasiRandomCtx>,
}
fn main() -> Result<()> {
let engine = Engine::default();
let mut linker = Linker::new(&engine);
let component = Component::new(&engine, "(component)")?;
let mut name_map = HashMap::new();
named_imports::wasi::random::random::add_to_linker::<MyStoreState, WasiRandomNamed<MyStoreState>>(
&mut linker,
&component,
|name| {
let len = name_map.len();
Ok(NamedId(*name_map.entry(name.to_string()).or_insert(len)))
},
|state| WasiCtxNamedView(state),
)?;
Ok(())
}
impl WasiRandomNamedView for MyStoreState {
fn random(&mut self, id: NamedId) -> &mut WasiRandomCtx {
self.states.get_mut(&id).expect("state for id")
}
}Trait Implementations
Sourceimpl<T> HasData for WasiRandomNamed<T>where
T: WasiRandomNamedView,
impl<T> HasData for WasiRandomNamed<T>where
T: WasiRandomNamedView,
Sourcetype Data<'a> = WasiCtxNamedView<'a, T>
type Data<'a> = WasiCtxNamedView<'a, T>
The data associated with this trait implementation, chiefly used as a
generic associated type to allow plumbing the
'a lifetime into the
definition here. Read moreAuto Trait Implementations
impl<T> Freeze for WasiRandomNamed<T>
impl<T> RefUnwindSafe for WasiRandomNamed<T>
impl<T> Send for WasiRandomNamed<T>
impl<T> Sync for WasiRandomNamed<T>
impl<T> Unpin for WasiRandomNamed<T>
impl<T> UnsafeUnpin for WasiRandomNamed<T>
impl<T> UnwindSafe for WasiRandomNamed<T>