SocketAddrUse

Enum SocketAddrUse 

pub enum SocketAddrUse {
    TcpBind,
    TcpListen,
    TcpAccept,
    TcpConnect,
    UdpBind,
    UdpSend,
    UdpReceive,
}
The reason what a socket address is being used for.

Variants



TcpBind

Binding TCP socket.

This is invoked for both explicit calls to bind as well as implicit binds that are about to be performed by the OS as part of e.g. connect & listen.

The address that is passed to the check is the address provided to bind for explicit binds, or the wildcard address for implicit binds.



TcpListen

Put a TCP socket in listener mode.

If the socket was already bound at the time of the call, the actual local address of the socket is passed to the check. If the socket is about to be implicitly bound by listen, the wildcard address is passed.



TcpAccept

Accepting a new client TCP socket.

The address passed to the check is the remote address of the client that is being accepted. If the check fails, the client socket will be silently dropped before reaching the guest.



TcpConnect

Connecting a TCP socket.

The address passed to the check is the remote address that the socket is attempting to connect to.



UdpBind

Binding UDP socket.

This is invoked for both explicit calls to bind as well as implicit binds that are about to be performed by the OS as part of e.g. connect & send.

The address that is passed to the check is the address provided to bind for explicit binds, or the wildcard address for implicit binds.



UdpSend

Sending a datagram on a UDP socket.

The address passed to the check is the remote address that the socket is attempting to send to.



UdpReceive

Receiving a datagram on a UDP socket.

The address passed to the check is the remote address of the datagram that is being received. If the check fails, the datagram will be silently dropped before reaching the guest.