pub struct NamedId(pub usize);Expand description
Identifier used to correlate a named import to a host-defined value.
This type is a small newtype wrapper around a usize, its only field which
is also public. Embeders define the meaning of this value and are in control
of both creating this an interpreting it. Creation of NamedId happens in
functions like wasmtime_wasi::p3::add_named_to_linker where embedders
will allocate a NamedId for all recognized named imports. Interpreting
a NamedId happens later in traits such as WasiNamedView where the id
is passed back to the embedder and a corresponding context must be returned.
Internally the wasmtime-wasi crate does not inspect the internal field
here nor ever create one. Embedders are solely responsible for managing this
id and its conetnts.
Tuple Fields
0: usizeTrait Implementations
impl Copy for NamedId
impl Eq for NamedId
Sourceimpl Ord for NamedId
impl Ord for NamedId
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialOrd for NamedId
impl PartialOrd for NamedId
impl StructuralPartialEq for NamedId