Struct wasmtime_wasi::Pollable
source · pub struct Pollable { /* private fields */ }Expand description
A host representation of the wasi:io/poll.pollable resource.
A pollable is not the same thing as a Rust Future: the same pollable may be used to
repeatedly check for readiness of a given condition, e.g. if a stream is readable
or writable. So, rather than containing a Future, which can only become Ready once, a
Pollable contains a way to create a Future in each call to poll.