WasiCtxNamedView

Struct WasiCtxNamedView 

pub struct WasiCtxNamedView<'a, T>(pub &'a mut T);
A helper structure by which to implement generated-Host traits for bindings corresponding to named imports.

This is an implementation detail of how named imports are organized. Embedders invoking generated add_to_linker functions directly will be required to create this structure directly. Otherwise you probably won’t need to interact with this.

Tuple Fields

0: &'a mut T