WasiNamedView

Trait WasiNamedView 

pub trait WasiNamedView: Send + 'static {
    // Required method
    fn ctx(&mut self, id: NamedId) -> WasiCtxView<'_>;
}
A trait which provides access to a specific WasiCtx as scoped by a NamedId parameter.

This trait is used as part of convenience wasmtime_wasi::p3::add_named_to_linker functions for example. This is used to scope access of a WASI context within a specific id or named import.

Required Methods

fn ctx(&mut self, id: NamedId) -> WasiCtxView<'_>

Yields mutable access to the WasiCtx configuration used for this context.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors