pub enum FsPerms {
ReadOnly,
ReadWrite,
}Expand description
Permission bits for operating on filesystem, specified per preopen, as enforced by wasmtime-wasi.
Filesystems can deny all mutation operations (read-only) or permit mutations (read-write).
Read-only permissions allow reading the contents of any file or directory reachable under the preopen, as well as reading any file metadata. Changing, appending, or truncating files is not permitted. Creating or deleting files, directories, symbolic links, and hard links are not permitted.
Read-write permissions include changing the contents of any reachable file, creating and deleting files, directories, symbolic links, and creating hard links, as well as mutating any file metadata.
These permissions are enforced by wasmtime-wasi. The host filesystem may enforce additional restrictions not covered by these.
Variants
Implementations